==> igniteui-webcomponents-core-1.4.2.tgz: package/esm5/lib/WebInputDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebInputDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebInputDescription, _super);
    function WebInputDescription() {
        var _this = _super.call(this) || this;
        _this.aa = null;
        _this.ab = null;
        _this.ad = null;
        _this.ai = null;
        _this.am = null;
        _this.aj = null;
        _this.af = null;
        _this.ak = null;
        _this.h = false;
        _this.i = false;
        _this.k = false;
        _this.g = false;
        _this.j = false;
        _this.s = 0;
        _this.r = 0;
        _this.ah = null;
        _this.ag = null;
        _this.t = 0;
        _this.f = false;
        _this.x = null;
        _this.al = null;
        _this.ae = null;
        _this.z = null;
        _this.ac = null;
        _this.y = null;
        return _this;
    }
    WebInputDescription.prototype.get_type = function () {
        return "WebInput";
    };
    Object.defineProperty(WebInputDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "dir", {
        get: function () {
            return this.aa;
        },
        set: function (a) {
            this.aa = a;
            this.e("Dir");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "displayType", {
        get: function () {
            return this.ab;
        },
        set: function (a) {
            this.ab = a;
            this.e("DisplayType");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "inputmode", {
        get: function () {
            return this.ad;
        },
        set: function (a) {
            this.ad = a;
            this.e("Inputmode");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "name", {
        get: function () {
            return this.ai;
        },
        set: function (a) {
            this.ai = a;
            this.e("Name");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "value", {
        get: function () {
            return this.am;
        },
        set: function (a) {
            this.am = a;
            this.e("Value");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "pattern", {
        get: function () {
            return this.aj;
        },
        set: function (a) {
            this.aj = a;
            this.e("Pattern");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "label", {
        get: function () {
            return this.af;
        },
        set: function (a) {
            this.af = a;
            this.e("Label");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "placeholder", {
        get: function () {
            return this.ak;
        },
        set: function (a) {
            this.ak = a;
            this.e("Placeholder");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "invalid", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("Invalid");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "outlined", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.e("Outlined");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "required", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e("Required");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "disabled", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("Disabled");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "readonly", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.e("Readonly");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "minlength", {
        get: function () {
            return this.s;
        },
        set: function (a) {
            this.s = a;
            this.e("Minlength");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "maxlength", {
        get: function () {
            return this.r;
        },
        set: function (a) {
            this.r = a;
            this.e("Maxlength");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "min", {
        get: function () {
            return this.ah;
        },
        set: function (a) {
            this.ah = a;
            this.e("Min");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "max", {
        get: function () {
            return this.ag;
        },
        set: function (a) {
            this.ag = a;
            this.e("Max");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "step", {
        get: function () {
            return this.t;
        },
        set: function (a) {
            this.t = a;
            this.e("Step");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "autofocus", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Autofocus");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "autocomplete", {
        get: function () {
            return this.x;
        },
        set: function (a) {
            this.x = a;
            this.e("Autocomplete");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "size", {
        get: function () {
            return this.al;
        },
        set: function (a) {
            this.al = a;
            this.e("Size");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "inputOcurredRef", {
        get: function () {
            return this.ae;
        },
        set: function (a) {
            this.ae = a;
            this.e("InputOcurredRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "changeRef", {
        get: function () {
            return this.z;
        },
        set: function (a) {
            this.z = a;
            this.e("ChangeRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "focusRef", {
        get: function () {
            return this.ac;
        },
        set: function (a) {
            this.ac = a;
            this.e("FocusRef");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "blurRef", {
        get: function () {
            return this.y;
        },
        set: function (a) {
            this.y = a;
            this.e("BlurRef");
        },
        enumerable: true,
        configurable: true
    });
    WebInputDescription.$t = markType(WebInputDescription, 'WebInputDescription', Description.$);
    return WebInputDescription;
}(Description));
export { WebInputDescription };

==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebInputDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { WebInputBaseDescription } from "./WebInputBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebInputDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebInputDescription, _super);
    function WebInputDescription() {
        var _this = _super.call(this) || this;
        _this.au = null;
        _this.ao = null;
        _this.ap = null;
        _this.aq = null;
        _this.at = null;
        _this.ad = false;
        _this.ah = 0;
        _this.ag = 0;
        _this.as = null;
        _this.ar = null;
        _this.ai = 0;
        _this.ac = false;
        _this.am = null;
        _this.an = null;
        return _this;
    }
    WebInputDescription.prototype.get_type = function () {
        return "WebInput";
    };
    Object.defineProperty(WebInputDescription.prototype, "value", {
        get: function () {
            return this.au;
        },
        set: function (a) {
            this.au = a;
            this.e("Value");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "dir", {
        get: function () {
            return this.ao;
        },
        set: function (a) {
            this.ao = a;
            this.e("Dir");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "displayType", {
        get: function () {
            return this.ap;
        },
        set: function (a) {
            this.ap = a;
            this.e("DisplayType");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "inputmode", {
        get: function () {
            return this.aq;
        },
        set: function (a) {
            this.aq = a;
            this.e("Inputmode");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "pattern", {
        get: function () {
            return this.at;
        },
        set: function (a) {
            this.at = a;
            this.e("Pattern");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "invalid", {
        get: function () {
            return this.ad;
        },
        set: function (a) {
            this.ad = a;
            this.e("Invalid");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "minlength", {
        get: function () {
            return this.ah;
        },
        set: function (a) {
            this.ah = a;
            this.e("Minlength");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "maxlength", {
        get: function () {
            return this.ag;
        },
        set: function (a) {
            this.ag = a;
            this.e("Maxlength");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "min", {
        get: function () {
            return this.as;
        },
        set: function (a) {
            this.as = a;
            this.e("Min");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "max", {
        get: function () {
            return this.ar;
        },
        set: function (a) {
            this.ar = a;
            this.e("Max");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "step", {
        get: function () {
            return this.ai;
        },
        set: function (a) {
            this.ai = a;
            this.e("Step");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "autofocus", {
        get: function () {
            return this.ac;
        },
        set: function (a) {
            this.ac = a;
            this.e("Autofocus");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "autocomplete", {
        get: function () {
            return this.am;
        },
        set: function (a) {
            this.am = a;
            this.e("Autocomplete");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebInputDescription.prototype, "changeRef", {
        get: function () {
            return this.an;
        },
        set: function (a) {
            this.an = a;
            this.e("ChangeRef");
        },
        enumerable: true,
        configurable: true
    });
    WebInputDescription.$t = markType(WebInputDescription, 'WebInputDescription', WebInputBaseDescription.$);
    return WebInputDescription;
}(WebInputBaseDescription));
export { WebInputDescription };
